/*
Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/


#ifndef RCONNECTION_H
#define RCONNECTION_H

#include <e32cons.h>
#include <in_sock.h>

#include <es_enum.h>
#include <commdbconnpref.h>

class CRConnection : public CBase
	{
public:
	
	//Constructor.
	CRConnection(CConsoleBase* aConsole);
	
	//Destructor.
	~CRConnection();
	
	//Opens a session to the socket server and opens a connection that monitors for interface notification.
	void StartESOCK();
	
	//Demonstrates various RConnection API methods using default Commdb settings.
	void DemoApiWithoutDbOverrideL();
	
	//Demonstrates various RConnection API methods using non-default Commdb settings.
	void DemoApiWithDbOverrideL();
	
	//Starts a connection then attaches another connection to the same interface.
	void AttachToExistingInterfaceL();
	
	//Opens and starts a connection using non-default Commdb settings.
	TInt ConnectWithDbOverrideL();
	
	//Opens and starts a connection using default Commdb settings.
	TInt ConnectWithoutDbOverrideL();
	
	//Requests notification of the connection's progress.
	void GetProgressNotification();
	
	//Prints progress information to the console.
	void DisplayProgressinfo(const TNifProgress& aProgress);
	
	//Displays text describing the next phase of the example.
	void DisplaySectionToDemo(const TDesC& aText);
	
	//Prepares the socket for carrying out data transfer.
	TInt PrepareSocket();
	
	//Sends UDP packets over a socket.
	TInt SendUdpData(TUint aPayloadSize);
	
	//Receives UDP packets over a socket.
	TInt RecvUdpData(TUint aPayloadSize);
	
	//Calls SendUdpData() and RecvUdpData().
	void DataSendAndReceive(TUint aPayloadSize);
	
	//Gets the amount of data that has been transferred by the entire connection.
	void DataTransferredRequest();
	
	//Requests notification when a certain amount of data has been sent or received.
	void DataTransferNotificationRequest();
	
	
private:
	RConnection 	iConnection;
	RSocket 		iSocket; 
	RSocketServ		iSocketServ;
	CConsoleBase* 	iConsole;
	TInetAddr 		iDestAddr;
	TInt 			iCurrentProgress;
	RConnection 	iMonitor;
 	
	};
	
#endif //RCONNECTION_H
